@@ -19,8 +19,10 @@ class JupyterProjectFactory:
         if JupyterProjectFactory.check_if_directory_exists(project_path=project_path):
             raise click.ClickException("Project directory already exists!")
 
-        template_data = {
-            "project_name": project_name
-        }
+        template_data = {"project_name": project_name}
 
-        copier.copy(src_path=(template_url or JUPYTER_TEMPLATE_PROJECT), dst_path=project_path, data=template_data)
+        copier.copy(
+            src_path=(template_url or JUPYTER_TEMPLATE_PROJECT),
+            dst_path=project_path,
+            data=template_data,
+        )
