@@ -2,5 +2,5 @@ from enum import Enum
 
 
 class ProjectType(Enum):
-    PYTHON = 'python'
-    JUPYTER = 'jupyter'
+    PYTHON = "python"
+    JUPYTER = "jupyter"
